use std::sync::Arc;

use como_core::{items::DynItemService, projects::DynProjectService, users::DynUserService};
use tracing::log::info;

use crate::{
    configs::AppConfig,
    database::ConnectionPool,
    services::{
        item_service::DefaultItemService, project_service::DefaultProjectService,
        user_service::DefaultUserService,
    },
};

#[derive(Clone)]
pub struct ServiceRegister {
    pub item_service: DynItemService,
    pub project_service: DynProjectService,
    pub user_service: DynUserService,
}

impl ServiceRegister {
    pub fn new(_pool: ConnectionPool, _config: AppConfig) -> Self {
        info!("creating services");

        let item_service = Arc::new(DefaultItemService::new()) as DynItemService;
        let project_service = Arc::new(DefaultProjectService::new()) as DynProjectService;
        let user_service = Arc::new(DefaultUserService::new()) as DynUserService;

        info!("services created succesfully");

        return Self {
            item_service,
            user_service,
            project_service,
        };
    }
}
